==> apache-trafficcontrol-3.0.0.tar.gz: apache-trafficcontrol-3.0.0/traffic_portal/app/src/modules/private/cacheGroups/parameters/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.cacheGroups.parameters', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.cacheGroups.parameters', {
				url: '/{cacheGroupId}/parameters',
				views: {
					cacheGroupsContent: {
						templateUrl: 'common/modules/table/cacheGroupParameters/table.cacheGroupParameters.tpl.html',
						controller: 'TableCacheGroupParametersController',
						resolve: {
							cacheGroup: function($stateParams, cacheGroupService) {
								return cacheGroupService.getCacheGroup($stateParams.cacheGroupId);
							},
							cacheGroupParameters: function($stateParams, cacheGroupParameterService) {
								return cacheGroupParameterService.getCacheGroupParameters($stateParams.cacheGroupId);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-5.1.6.tar.gz: apache-trafficcontrol-5.1.6/traffic_portal/app/src/modules/private/cacheGroups/parameters/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.cacheGroups.parameters', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.cacheGroups.parameters', {
				url: '/{cacheGroupId}/parameters',
				views: {
					cacheGroupsContent: {
						templateUrl: 'common/modules/table/cacheGroupParameters/table.cacheGroupParameters.tpl.html',
						controller: 'TableCacheGroupParametersController',
						resolve: {
							cacheGroup: function($stateParams, cacheGroupService) {
								return cacheGroupService.getCacheGroup($stateParams.cacheGroupId);
							},
							parameters: function($stateParams, cacheGroupParameterService) {
								return cacheGroupParameterService.getCacheGroupParameters($stateParams.cacheGroupId);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
